function nmc = make_network(Pool_size,nInputChannels,Inoise)

%
% DEFINE PARAMETERS
%


% neuron parameters of the recurrent network

IINJECT  = [13.5e-09  13.5e-09];  % [A]
VRESET   = [13.5e-03  13.5e-03];  % [V]
VINIT    = [13.5e-03  15.0e-03];  % [V]

% recurrent network connectivity parameters

CSCALE   = 1;
WSCALE   = 2.5;
LAMBDA   = 1.5;
FRAC_EXZ = 0.8;  % [%]

SH_W     = 0.5;  % [% of the mean]
SH_UDF   = 0.5;  % [% of the mean]
SH_DELAY = 0.0;  % [% of the mean]


% input connectivity parameters

CINP     = 0.3;
WINP     = 18e-9;
SH_WINP  = 0.5;  % [% of the mean]

%
% initialize a liquid
%

nmc = neural_microcircuit;

%
% create a pool of leaky I&F neurons
%

[nmc,p1] = add(nmc,'Pool','origin',[5 1 1],'size',Pool_size,'frac_EXC',FRAC_EXZ,...
               'Neuron.Iinject',IINJECT,'Neuron.Inoise',Inoise,...
	       'Neuron.Vreset',VRESET,'Neuron.Vinit',VINIT);

%
% create one pool of spiking input neurons
%

[nmc,pin] = add(nmc,'Pool','origin',[1 1 1],'size',[1 1 nInputChannels],...
                'type','SpikingInputNeuron','frac_EXC',1);

%
% connect the input to the pool of leaky I&F neurons
%

nmc = add(nmc,'Conn','dest',p1,'src',pin,'Cscale',CINP,'C(IE)',0,'C(EE)',1,'type','StaticSpikingSynapse',...
    'rescale',0,'Synapse(EE).W',WINP,'SH_W',SH_WINP,'lambda',Inf);

%
% add recurrent connections within the pools
%

nmc = add(nmc,'Conn','dest',p1,'src',p1,'lambda',LAMBDA,...
          'SH_W',SH_W,'SH_UDF',SH_UDF,'SH_delay',SH_DELAY);

%
% define the respones (i.e. what to record)
%
nmc = record(nmc,'Pool',p1,'Field','spikes');

